use clap::ArgMatches;

pub struct Configurator {
    pub args: ArgMatches,
}
